@@ -42,9 +42,11 @@ class BitwiseAndExpression;
 class BitwiseOrExpression;
 class ShiftLeftExpression;
 class ShiftRightExpression;
-class ForIntExpression;
+class ForDictExpression;
+class ForArrayExpression;
 class ForStringExpression;
 class OfExpression;
+class IterableExpression;
 class SetExpression;
 class RangeExpression;
 class IdExpression;
@@ -104,9 +106,11 @@ public:
 	virtual VisitResult visit(BitwiseOrExpression* expr) = 0;
 	virtual VisitResult visit(ShiftLeftExpression* expr) = 0;
 	virtual VisitResult visit(ShiftRightExpression* expr) = 0;
-	virtual VisitResult visit(ForIntExpression* expr) = 0;
+	virtual VisitResult visit(ForDictExpression* expr) = 0;
+	virtual VisitResult visit(ForArrayExpression* expr) = 0;
 	virtual VisitResult visit(ForStringExpression* expr) = 0;
 	virtual VisitResult visit(OfExpression* expr) = 0;
+	virtual VisitResult visit(IterableExpression* expr) = 0;
 	virtual VisitResult visit(SetExpression* expr) = 0;
 	virtual VisitResult visit(RangeExpression* expr) = 0;
 	virtual VisitResult visit(IdExpression* expr) = 0;
