@@ -49,9 +49,11 @@ void addVisitorClasses(py::module& module)
 		.def("visit_BitwiseOrExpression", py::overload_cast<BitwiseOrExpression*>(&Visitor::visit))
 		.def("visit_ShiftLeftExpression", py::overload_cast<ShiftLeftExpression*>(&Visitor::visit))
 		.def("visit_ShiftRightExpression", py::overload_cast<ShiftRightExpression*>(&Visitor::visit))
-		.def("visit_ForIntExpression", py::overload_cast<ForIntExpression*>(&Visitor::visit))
+		.def("visit_ForDictExpression", py::overload_cast<ForDictExpression*>(&Visitor::visit))
+		.def("visit_ForArrayExpression", py::overload_cast<ForArrayExpression*>(&Visitor::visit))
 		.def("visit_ForStringExpression", py::overload_cast<ForStringExpression*>(&Visitor::visit))
 		.def("visit_OfExpression", py::overload_cast<OfExpression*>(&Visitor::visit))
+		.def("visit_IterableExpression", py::overload_cast<IterableExpression*>(&Visitor::visit))
 		.def("visit_SetExpression", py::overload_cast<SetExpression*>(&Visitor::visit))
 		.def("visit_RangeExpression", py::overload_cast<RangeExpression*>(&Visitor::visit))
 		.def("visit_IdExpression", py::overload_cast<IdExpression*>(&Visitor::visit))
@@ -104,9 +106,11 @@ void addVisitorClasses(py::module& module)
 		.def("visit_BitwiseOrExpression", py::overload_cast<BitwiseOrExpression*>(&ObservingVisitor::visit))
 		.def("visit_ShiftLeftExpression", py::overload_cast<ShiftLeftExpression*>(&ObservingVisitor::visit))
 		.def("visit_ShiftRightExpression", py::overload_cast<ShiftRightExpression*>(&ObservingVisitor::visit))
-		.def("visit_ForIntExpression", py::overload_cast<ForIntExpression*>(&ObservingVisitor::visit))
+		.def("visit_ForDictExpression", py::overload_cast<ForDictExpression*>(&ObservingVisitor::visit))
+		.def("visit_ForArrayExpression", py::overload_cast<ForArrayExpression*>(&ObservingVisitor::visit))
 		.def("visit_ForStringExpression", py::overload_cast<ForStringExpression*>(&ObservingVisitor::visit))
 		.def("visit_OfExpression", py::overload_cast<OfExpression*>(&ObservingVisitor::visit))
+		.def("visit_IterableExpression", py::overload_cast<IterableExpression*>(&ObservingVisitor::visit))
 		.def("visit_SetExpression", py::overload_cast<SetExpression*>(&ObservingVisitor::visit))
 		.def("visit_RangeExpression", py::overload_cast<RangeExpression*>(&ObservingVisitor::visit))
 		.def("visit_IdExpression", py::overload_cast<IdExpression*>(&ObservingVisitor::visit))
@@ -160,9 +164,11 @@ void addVisitorClasses(py::module& module)
 		.def("visit_BitwiseOrExpression", py::overload_cast<BitwiseOrExpression*>(&ModifyingVisitor::visit))
 		.def("visit_ShiftLeftExpression", py::overload_cast<ShiftLeftExpression*>(&ModifyingVisitor::visit))
 		.def("visit_ShiftRightExpression", py::overload_cast<ShiftRightExpression*>(&ModifyingVisitor::visit))
-		.def("visit_ForIntExpression", py::overload_cast<ForIntExpression*>(&ModifyingVisitor::visit))
+		.def("visit_ForDictExpression", py::overload_cast<ForDictExpression*>(&ModifyingVisitor::visit))
+		.def("visit_ForArrayExpression", py::overload_cast<ForArrayExpression*>(&ModifyingVisitor::visit))
 		.def("visit_ForStringExpression", py::overload_cast<ForStringExpression*>(&ModifyingVisitor::visit))
 		.def("visit_OfExpression", py::overload_cast<OfExpression*>(&ModifyingVisitor::visit))
+		.def("visit_IterableExpression", py::overload_cast<IterableExpression*>(&ModifyingVisitor::visit))
 		.def("visit_SetExpression", py::overload_cast<SetExpression*>(&ModifyingVisitor::visit))
 		.def("visit_RangeExpression", py::overload_cast<RangeExpression*>(&ModifyingVisitor::visit))
 		.def("visit_IdExpression", py::overload_cast<IdExpression*>(&ModifyingVisitor::visit))
@@ -208,9 +214,11 @@ void addVisitorClasses(py::module& module)
 		.def("default_handler", static_cast<VisitResult(ModifyingVisitor::*)(const TokenStreamContext&, BitwiseOrExpression*, const VisitResult&, const VisitResult&)>(&ModifyingVisitor::defaultHandler))
 		.def("default_handler", static_cast<VisitResult(ModifyingVisitor::*)(const TokenStreamContext&, ShiftLeftExpression*, const VisitResult&, const VisitResult&)>(&ModifyingVisitor::defaultHandler))
 		.def("default_handler", static_cast<VisitResult(ModifyingVisitor::*)(const TokenStreamContext&, ShiftRightExpression*, const VisitResult&, const VisitResult&)>(&ModifyingVisitor::defaultHandler))
-		.def("default_handler", static_cast<VisitResult(ModifyingVisitor::*)(const TokenStreamContext&, ForIntExpression*, const VisitResult&, const VisitResult&, const VisitResult&)>(&ModifyingVisitor::defaultHandler))
+		.def("default_handler", static_cast<VisitResult(ModifyingVisitor::*)(const TokenStreamContext&, ForDictExpression*, const VisitResult&, const VisitResult&, const VisitResult&)>(&ModifyingVisitor::defaultHandler))
+		.def("default_handler", static_cast<VisitResult(ModifyingVisitor::*)(const TokenStreamContext&, ForArrayExpression*, const VisitResult&, const VisitResult&, const VisitResult&)>(&ModifyingVisitor::defaultHandler))
 		.def("default_handler", static_cast<VisitResult(ModifyingVisitor::*)(const TokenStreamContext&, ForStringExpression*, const VisitResult&, const VisitResult&, const VisitResult&)>(&ModifyingVisitor::defaultHandler))
 		.def("default_handler", static_cast<VisitResult(ModifyingVisitor::*)(const TokenStreamContext&, OfExpression*, const VisitResult&, const VisitResult&, const VisitResult&)>(&ModifyingVisitor::defaultHandler))
+		.def("default_handler", static_cast<VisitResult(ModifyingVisitor::*)(const TokenStreamContext&, IterableExpression*, const std::vector<VisitResult>&)>(&ModifyingVisitor::defaultHandler))
 		.def("default_handler", static_cast<VisitResult(ModifyingVisitor::*)(const TokenStreamContext&, SetExpression*, const std::vector<VisitResult>&)>(&ModifyingVisitor::defaultHandler))
 		.def("default_handler", static_cast<VisitResult(ModifyingVisitor::*)(const TokenStreamContext&, RangeExpression*, const VisitResult&, const VisitResult&)>(&ModifyingVisitor::defaultHandler))
 		.def("default_handler", static_cast<VisitResult(ModifyingVisitor::*)(const TokenStreamContext&, StructAccessExpression*, const VisitResult&)>(&ModifyingVisitor::defaultHandler))
