@@ -63,7 +63,8 @@ void addEnums(py::module& module)
 {
 	py::enum_<ParserMode>(module, "ParserMode")
 		.value("Regular", ParserMode::Regular)
-		.value("IncludeGuarded", ParserMode::IncludeGuarded);
+		.value("IncludeGuarded", ParserMode::IncludeGuarded)
+		.value("Incomplete", ParserMode::Incomplete);
 
 	py::enum_<Features>(module, "Features", py::arithmetic())
 		.value("Basic", Features::Basic)
@@ -229,8 +230,11 @@ void addEnums(py::module& module)
 		.value("ArraySymbol", TokenType::ARRAY_SYMBOL)
 		.value("DictionarySymbol", TokenType::DICTIONARY_SYMBOL)
 		.value("StructureSymbol", TokenType::STRUCTURE_SYMBOL)
+		.value("ReferenceSymbol", TokenType::REFERENCE_SYMBOL)
 		.value("LpEnumeration", TokenType::LP_ENUMERATION)
 		.value("RpEnumeration", TokenType::RP_ENUMERATION)
+		.value("LsqbEnumeration", TokenType::LSQB_ENUMERATION)
+		.value("RsqbEnumeration", TokenType::RSQB_ENUMERATION)
 		.value("LpWithSpaceAfter", TokenType::LP_WITH_SPACE_AFTER)
 		.value("RpWithSpaceBefore", TokenType::RP_WITH_SPACE_BEFORE)
 		.value("LpWithSpaces", TokenType::LP_WITH_SPACES)
