@@ -14,22 +14,22 @@ namespace yaramod {
 /**
  * Constructor.
  */
-YaraFile::YaraFile(ImportFeatures features)
+YaraFile::YaraFile(Features features)
 	: YaraFile(std::make_shared<TokenStream>(), features)
 {
-	if (_importFeatures & ImportFeatures::VirusTotalOnly)
+	if (_Features & Features::VirusTotalOnly)
 		initializeVTSymbols();
 }
 
-YaraFile::YaraFile(const std::shared_ptr<TokenStream>& tokenStream, ImportFeatures features)
+YaraFile::YaraFile(const std::shared_ptr<TokenStream>& tokenStream, Features features)
 	: _tokenStream(std::move(tokenStream))
 	, _imports()
 	, _rules()
 	, _importTable()
 	, _ruleTable()
-	, _importFeatures(features)
+	, _Features(features)
 {
-	if (_importFeatures & ImportFeatures::VirusTotalOnly)
+	if (_Features & Features::VirusTotalOnly)
 		initializeVTSymbols();
 }
 
@@ -39,7 +39,7 @@ YaraFile::YaraFile(YaraFile&& o) noexcept
 	, _rules(std::move(o._rules))
 	, _importTable(std::move(o._importTable))
 	, _ruleTable(std::move(o._ruleTable))
-	, _importFeatures(std::move(o._importFeatures))
+	, _Features(std::move(o._Features))
 	, _vtSymbols(std::move(o._vtSymbols))
 {
 }
@@ -51,7 +51,7 @@ YaraFile& YaraFile::operator=(YaraFile&& o) noexcept
 	std::swap(_rules, o._rules);
 	std::swap(_importTable, o._importTable);
 	std::swap(_ruleTable, o._ruleTable);
-	std::swap(_importFeatures, o._importFeatures);
+	std::swap(_Features, o._Features);
 	std::swap(_vtSymbols, o._vtSymbols);
 	return *this;
 }
@@ -74,6 +74,7 @@ void YaraFile::initializeVTSymbols()
 		std::make_shared<ValueSymbol>("file_name", Expression::Type::String),
 		// VirusTotal specific global variables of antiviruses
 		std::make_shared<ValueSymbol>("a_squared", Expression::Type::String),
+		std::make_shared<ValueSymbol>("acronis", Expression::Type::String),
 		std::make_shared<ValueSymbol>("ad_aware", Expression::Type::String),
 		std::make_shared<ValueSymbol>("aegislab", Expression::Type::String),
 		std::make_shared<ValueSymbol>("agnitum", Expression::Type::String),
@@ -84,9 +85,11 @@ void YaraFile::initializeVTSymbols()
 		std::make_shared<ValueSymbol>("antivir", Expression::Type::String),
 		std::make_shared<ValueSymbol>("antivir7", Expression::Type::String),
 		std::make_shared<ValueSymbol>("antiy_avl", Expression::Type::String),
+		std::make_shared<ValueSymbol>("apex", Expression::Type::String),
 		std::make_shared<ValueSymbol>("arcabit", Expression::Type::String),
 		std::make_shared<ValueSymbol>("authentium", Expression::Type::String),
 		std::make_shared<ValueSymbol>("avast", Expression::Type::String),
+		std::make_shared<ValueSymbol>("avast_mobile", Expression::Type::String),
 		std::make_shared<ValueSymbol>("avg", Expression::Type::String),
 		std::make_shared<ValueSymbol>("avira", Expression::Type::String),
 		std::make_shared<ValueSymbol>("avware", Expression::Type::String),
@@ -100,9 +103,14 @@ void YaraFile::initializeVTSymbols()
 		std::make_shared<ValueSymbol>("commtouch", Expression::Type::String),
 		std::make_shared<ValueSymbol>("comodo", Expression::Type::String),
 		std::make_shared<ValueSymbol>("crowdstrike", Expression::Type::String),
+		std::make_shared<ValueSymbol>("cybereason", Expression::Type::String),
+		std::make_shared<ValueSymbol>("cylance", Expression::Type::String),
+		std::make_shared<ValueSymbol>("cynet", Expression::Type::String),
 		std::make_shared<ValueSymbol>("cyren", Expression::Type::String),
 		std::make_shared<ValueSymbol>("drweb", Expression::Type::String),
+		std::make_shared<ValueSymbol>("egambit", Expression::Type::String),
 		std::make_shared<ValueSymbol>("emsisoft", Expression::Type::String),
+		std::make_shared<ValueSymbol>("endgame", Expression::Type::String),
 		std::make_shared<ValueSymbol>("esafe", Expression::Type::String),
 		std::make_shared<ValueSymbol>("escan", Expression::Type::String),
 		std::make_shared<ValueSymbol>("eset_nod32", Expression::Type::String),
@@ -118,6 +126,8 @@ void YaraFile::initializeVTSymbols()
 		std::make_shared<ValueSymbol>("kaspersky", Expression::Type::String),
 		std::make_shared<ValueSymbol>("kingsoft", Expression::Type::String),
 		std::make_shared<ValueSymbol>("malwarebytes", Expression::Type::String),
+		std::make_shared<ValueSymbol>("max", Expression::Type::String),
+		std::make_shared<ValueSymbol>("maxsecure", Expression::Type::String),
 		std::make_shared<ValueSymbol>("mcafee", Expression::Type::String),
 		std::make_shared<ValueSymbol>("mcafee_gw_edition", Expression::Type::String),
 		std::make_shared<ValueSymbol>("microsoft", Expression::Type::String),
@@ -126,26 +136,35 @@ void YaraFile::initializeVTSymbols()
 		std::make_shared<ValueSymbol>("nod32", Expression::Type::String),
 		std::make_shared<ValueSymbol>("norman", Expression::Type::String),
 		std::make_shared<ValueSymbol>("nprotect", Expression::Type::String),
+		std::make_shared<ValueSymbol>("paloalto", Expression::Type::String),
 		std::make_shared<ValueSymbol>("panda", Expression::Type::String),
 		std::make_shared<ValueSymbol>("pctools", Expression::Type::String),
 		std::make_shared<ValueSymbol>("prevx", Expression::Type::String),
 		std::make_shared<ValueSymbol>("prevx1", Expression::Type::String),
 		std::make_shared<ValueSymbol>("qihoo_360", Expression::Type::String),
 		std::make_shared<ValueSymbol>("rising", Expression::Type::String),
+		std::make_shared<ValueSymbol>("sangfor", Expression::Type::String),
+		std::make_shared<ValueSymbol>("sentinelone", Expression::Type::String),
 		std::make_shared<ValueSymbol>("sophos", Expression::Type::String),
 		std::make_shared<ValueSymbol>("sunbelt", Expression::Type::String),
 		std::make_shared<ValueSymbol>("superantispyware", Expression::Type::String),
 		std::make_shared<ValueSymbol>("symantec", Expression::Type::String),
+		std::make_shared<ValueSymbol>("symantecmobileinsight", Expression::Type::String),
+		std::make_shared<ValueSymbol>("tachyon", Expression::Type::String),
 		std::make_shared<ValueSymbol>("tencent", Expression::Type::String),
 		std::make_shared<ValueSymbol>("thehacker", Expression::Type::String),
 		std::make_shared<ValueSymbol>("totaldefense", Expression::Type::String),
 		std::make_shared<ValueSymbol>("trendmicro", Expression::Type::String),
 		std::make_shared<ValueSymbol>("trendmicro_housecall", Expression::Type::String),
+		std::make_shared<ValueSymbol>("trustlook", Expression::Type::String),
 		std::make_shared<ValueSymbol>("vba32", Expression::Type::String),
 		std::make_shared<ValueSymbol>("vipre", Expression::Type::String),
 		std::make_shared<ValueSymbol>("virobot", Expression::Type::String),
+		std::make_shared<ValueSymbol>("webroot", Expression::Type::String),
+		std::make_shared<ValueSymbol>("whitearmor", Expression::Type::String),
 		std::make_shared<ValueSymbol>("yandex", Expression::Type::String),
 		std::make_shared<ValueSymbol>("zillya", Expression::Type::String),
+		std::make_shared<ValueSymbol>("zonealarm", Expression::Type::String),
 		std::make_shared<ValueSymbol>("zoner", Expression::Type::String)
 	};
 }
@@ -188,12 +207,13 @@ std::string YaraFile::getTextFormatted(bool withIncludes) const
  * to exist and be defined in @c types/modules folder.
  *
  * @param import Imported module name.
+ * @param modules A pool where to add module.
  *
  * @return @c true if module was found, @c false otherwise.
  */
-bool YaraFile::addImport(TokenIt import, ModulesPool& modules)
+bool YaraFile::addImport(TokenIt import, ModulePool& modules)
 {
-	auto module = modules.load(import->getPureText(), _importFeatures);
+	auto module = modules.load(import->getPureText());
 	if (!module)
 		return false;
 
@@ -206,6 +226,26 @@ bool YaraFile::addImport(TokenIt import, ModulesPool& modules)
 	return true;
 }
 
+/**
+ * Adds the imports of the modules to the YARA file. Modules need
+ * to exist and be defined in @c types/modules folder.
+ *
+ * @param imports Imported modules names.
+ * @param modules A pool where to add the modules.
+ *
+ * @return @c true if modules were found, @c false otherwise.
+ */
+bool YaraFile::addImports(const std::vector<TokenIt>& imports, ModulePool& modules)
+{
+	for (const TokenIt& module : imports)
+	{
+		if (!addImport(module, modules))
+			return false;
+	}
+
+	return true;
+}
+
 /**
  * Adds the rule to the YARA file.
  *
@@ -257,25 +297,6 @@ void YaraFile::addRules(const std::vector<std::shared_ptr<Rule>>& rules, bool ex
 		addRule(rule, extractTokens);
 }
 
-/**
- * Adds the imports of the modules to the YARA file. Modules need
- * to exist and be defined in @c types/modules folder.
- *
- * @param imports Imported modules names.
- *
- * @return @c true if modules were found, @c false otherwise.
- */
-bool YaraFile::addImports(const std::vector<TokenIt>& imports, ModulesPool& modules)
-{
-	for (const TokenIt& module : imports)
-	{
-		if (!addImport(module, modules))
-			return false;
-	}
-
-	return true;
-}
-
 /**
  * Insert single rule at the specified position to the YARA file.
  *
